translate.convert.php2po

Package translate :: Package convert :: Module php2po |
[hide private]
[frames] | no frames]

# Module php2po

source code

convert PHP localization files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/php2po for examples and usage instructions

Classes | [hide private]
| php2po convert a .php file to a .po file for handling the translation...

Functions | [hide private]
convertphp(inputfile, outputfile, templatefile, pot=False, duplicatestyle="msgctxt") reads in inputfile using php, converts using php2po, writes to outputfile | source code
main(argv=None) | source code

Imports: sys, po, php